@@ -53,10 +53,10 @@ def starting_offset(source_code, offset):
 
 def get_doc(project, source_code, offset, resource=None, maxfixes=1):
     """Get the pydoc"""
-    pymodule = fixsyntax.get_pymodule(project.pycore,
-                                       source_code, resource, maxfixes)
-    pyname = fixsyntax.find_pyname_at(project, source_code,
-                                       offset, pymodule, maxfixes)
+    fixer = fixsyntax.FixSyntax(project.pycore, source_code,
+                                resource, maxfixes)
+    pymodule = fixer.get_pymodule()
+    pyname = fixer.pyname_at(offset)
     if pyname is None:
         return None
     pyobject = pyname.get_object()
@@ -88,10 +88,10 @@ def get_calltip(project, source_code, offset, resource=None,
     If `remove_self` is `True`, the first parameter whose name is self
     will be removed for methods.
     """
-    pymodule = fixsyntax.get_pymodule(project.pycore, source_code,
-                                       resource, maxfixes)
-    pyname = fixsyntax.find_pyname_at(project, source_code,
-                                       offset, pymodule, maxfixes)
+    fixer = fixsyntax.FixSyntax(project.pycore, source_code,
+                                resource, maxfixes)
+    pymodule = fixer.get_pymodule()
+    pyname = fixer.pyname_at(offset)
     if pyname is None:
         return None
     pyobject = pyname.get_object()
@@ -108,10 +108,10 @@ def get_definition_location(project, source_code, offset,
     location cannot be determined ``(None, None)`` is returned.
 
     """
-    pymodule = fixsyntax.get_pymodule(project.pycore, source_code,
-                                       resource, maxfixes)
-    pyname = fixsyntax.find_pyname_at(project, source_code, offset,
-                                       pymodule, maxfixes)
+    fixer = fixsyntax.FixSyntax(project.pycore, source_code,
+                                resource, maxfixes)
+    pymodule = fixer.get_pymodule()
+    pyname = fixer.pyname_at(offset)
     if pyname is not None:
         module, lineno = pyname.get_definition_location()
         if module is not None:
@@ -149,9 +149,10 @@ class CompletionProposal(CodeAssistProposal):
 
     """
 
-    def __init__(self, name, kind, type=None):
+    def __init__(self, name, kind, type=None, pyname=None):
         super(CompletionProposal, self).__init__(name, kind)
         self.type = type
+        self.pyname = pyname
 
     def __str__(self):
         return '%s (%s, %s)' % (self.name, self.kind, self.type)
@@ -159,6 +160,20 @@ class CompletionProposal(CodeAssistProposal):
     def __repr__(self):
         return str(self)
 
+    @property
+    def parameters(self):
+        """The names of the parameters the function takes.
+
+        Returns None if this completion is not a function.
+        """
+        pyname = self.pyname
+        if isinstance(pyname, pynames.ImportedName):
+            pyname = pyname._get_imported_pyname()
+        if isinstance(pyname, pynames.DefinedName):
+            pyobject = pyname.get_object()
+            if isinstance(pyobject, pyobject.AbstractFunction):
+                return pyobject.get_param_names()
+
 
 def sorted_proposals(proposals, kindpref=None, typepref=None):
     """Sort a list of proposals
@@ -241,7 +256,7 @@ class _PythonCodeAssist(object):
             for name, pyname in element.get_attributes().items():
                 if name.startswith(self.starting):
                     result[name] = CompletionProposal(
-                        name, 'attribute', self._get_pyname_type(pyname))
+                        name, 'attribute', self._get_pyname_type(pyname), pyname)
         return result
 
     def _undotted_completions(self, scope, result, lineno=None):
@@ -259,7 +274,7 @@ class _PythonCodeAssist(object):
                 if lineno is None or self.later_locals or \
                    not self._is_defined_after(scope, pyname, lineno):
                     result[name] = CompletionProposal(
-                        name, kind, self._get_pyname_type(pyname))
+                        name, kind, self._get_pyname_type(pyname), pyname)
 
     def _from_import_completions(self, pymodule):
         module_name = self.word_finder.get_from_module(self.offset)
@@ -270,7 +285,8 @@ class _PythonCodeAssist(object):
         for name in pymodule:
             if name.startswith(self.starting):
                 result[name] = CompletionProposal(name, kind='global',
-                                                  type='imported')
+                                                  type='imported',
+                                                  pyname=pymodule[name])
         return result
 
     def _find_module(self, pymodule, module_name):
@@ -307,8 +323,9 @@ class _PythonCodeAssist(object):
 
     def _code_completions(self):
         lineno = self.code.count('\n', 0, self.offset) + 1
-        pymodule = fixsyntax.get_pymodule(self.pycore, self.code,
-                                           self.resource, self.maxfixes)
+        fixer = fixsyntax.FixSyntax(self.pycore, self.code,
+                                    self.resource, self.maxfixes)
+        pymodule = fixer.get_pymodule()
         module_scope = pymodule.get_scope()
         code = pymodule.source_code
         lines = code.split('\n')
