@@ -8,7 +8,7 @@ class AutoImportTest(unittest.TestCase):
 
     def setUp(self):
         super(AutoImportTest, self).setUp()
-        self.project = testutils.sample_project()
+        self.project = testutils.sample_project(extension_modules=['sys'])
         self.mod1 = testutils.create_module(self.project, 'mod1')
         self.pkg = testutils.create_package(self.project, 'pkg')
         self.mod2 = testutils.create_module(self.project, 'mod2', self.pkg)
@@ -121,6 +121,11 @@ class AutoImportTest(unittest.TestCase):
         self.importer.update_module('sys')
         self.assertTrue('sys' in self.importer.get_modules('exit'))
 
+    def test_submodules(self):
+        self.assertEquals(set([self.mod1]),
+                          autoimport.submodules(self.mod1))
+        self.assertEquals(set([self.mod2, self.pkg]),
+                          autoimport.submodules(self.pkg))
 
 class AutoImportObservingTest(unittest.TestCase):
 
