@@ -826,6 +826,37 @@ class ExtractMethodTest(unittest.TestCase):
         expected = '\ndef f():\n    return "1" "2"\n\ns = (f())\n'
         self.assertEquals(expected, refactored)
 
+    def test_passing_conditional_updated_vars_in_extracted(self):
+        code = 'def f(a):\n' \
+               '    if 0:\n' \
+               '        a = 1\n' \
+               '    print(a)\n'
+        start, end = self._convert_line_range_to_offset(code, 2, 4)
+        refactored = self.do_extract_method(code, start, end, 'g')
+        expected = 'def f(a):\n' \
+                   '    g(a)\n\n' \
+                   'def g(a):\n' \
+                   '    if 0:\n' \
+                   '        a = 1\n' \
+                   '    print(a)\n'
+        self.assertEquals(expected, refactored)
+
+    def test_returning_conditional_updated_vars_in_extracted(self):
+        code = 'def f(a):\n' \
+               '    if 0:\n' \
+               '        a = 1\n' \
+               '    print(a)\n'
+        start, end = self._convert_line_range_to_offset(code, 2, 3)
+        refactored = self.do_extract_method(code, start, end, 'g')
+        expected = 'def f(a):\n' \
+                   '    a = g(a)\n' \
+                   '    print(a)\n\n' \
+                   'def g(a):\n' \
+                   '    if 0:\n' \
+                   '        a = 1\n' \
+                   '    return a\n'
+        self.assertEquals(expected, refactored)
+
 
 if __name__ == '__main__':
     unittest.main()
